# Correlation for Repeated Observation within Subjects in Python

This package applied the statistical technique for estimating the correlation for paired measures assessed on two or more ocassions for multiple subjects.
Pearson correlation is applied when each paired of measurements is independent of one another. This is not the case when you have an observation for the same subject at different times. 

## Installing

You can use PyPi to do so,

```shell
pip install intraCorr
```


## Contributing

You can contribute to this project by forking it through github. 

## Licensing

The code in this project is licensed under MIT license.

## Authors

* Erika Munoz
* Jose Nandez